EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedPackageFilters_CreateOrUpdatePackageFilter',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Sequence_Number',
    /* Description_Text        */ 'Creates a new feed package filter or updates an existing one.'
GO

IF OBJECT_ID('[FeedPackageFilters_CreateOrUpdatePackageFilter]') IS NOT NULL DROP PROCEDURE [FeedPackageFilters_CreateOrUpdatePackageFilter]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [FeedPackageFilters_CreateOrUpdatePackageFilter]
(
	@Feed_Id INT,
	@PackageFilter_Name NVARCHAR(50),
	@PackageFilter_Configuration XML,
	@Sequence_Number INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Sequence_Number IS NOT NULL
	BEGIN

		UPDATE [FeedPackageFilters]
		   SET [PackageFilter_Name] = @PackageFilter_Name,
			   [PackageFilter_Configuration] = @PackageFilter_Configuration
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Sequence_Number] = @Sequence_Number

	END
	ELSE
	BEGIN

		SET @Sequence_Number = (SELECT COALESCE(MAX([Sequence_Number]), 0) + 1
			                      FROM [FeedPackageFilters]
								 WHERE [Feed_Id] = @Feed_Id)

		INSERT INTO [FeedPackageFilters]
		(
			[Feed_Id],
			[Sequence_Number],
			[PackageFilter_Name],
			[PackageFilter_Configuration]
		)
		VALUES
		(
			@Feed_Id,
			@Sequence_Number,
			@PackageFilter_Name,
			@PackageFilter_Configuration
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [FeedPackageFilters_CreateOrUpdatePackageFilter] TO [ProGetUser_Role]
GO
	   

