EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NpmConnectors_GetPackages',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'NpmConnectorPackages',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the npm connector packages which match the specified criteria.'
GO

IF OBJECT_ID('[NpmConnectors_GetPackages]') IS NOT NULL DROP PROCEDURE [NpmConnectors_GetPackages]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NpmConnectors_GetPackages]
(
	@Connector_Id INT,
	@IncludeName_Csv NVARCHAR(MAX),
	@ExcludeName_Csv NVARCHAR(MAX),
	@ModifiedAfter_Date DATETIME,
	@MaxResults_Count INT
)
AS BEGIN

	SET NOCOUNT ON

	DECLARE @Includes TABLE ([Filter_Text] NVARCHAR(200) NOT NULL)
	DECLARE @Excludes TABLE ([Filter_Text] NVARCHAR(200) NOT NULL)

	INSERT INTO @Includes SELECT [Value_Text] FROM dbo.CsvToTable(@IncludeName_Csv, ',')
	INSERT INTO @Excludes SELECT [Value_Text] FROM dbo.CsvToTable(@ExcludeName_Csv, ',')

	DECLARE @Include_Count INT
	SET @Include_Count = (SELECT COUNT(*) FROM @Includes)

	IF @MaxResults_Count IS NOT NULL
		SET ROWCOUNT @MaxResults_Count

	SELECT *
	  FROM [NpmConnectorPackages]
	 WHERE [Connector_Id] = @Connector_Id
	   AND (@ModifiedAfter_Date IS NULL OR [Modified_Date] >= @ModifiedAfter_Date)
	   AND NOT EXISTS(SELECT *
	                    FROM @Excludes
					   WHERE [Package_Name] LIKE [Filter_Text])
	   AND (SELECT COUNT(*)
		      FROM @Includes
			 WHERE [Package_Name] LIKE [Filter_Text]) = @Include_Count
	 ORDER BY [Modified_Date] DESC

END
GO

GRANT EXECUTE ON [NpmConnectors_GetPackages] TO [ProGetUser_Role]
GO
